@@ -14,11 +14,16 @@ def isnan(a):
     return anp.isnan(a)
 
 
-@dispatch(Numeric)
+@dispatch(AGNumeric)
 def device(a):
     return "cpu"
 
 
+@dispatch(AGNumeric)
+def move_to_active_device(a):
+    return a
+
+
 @dispatch(AGDType, AGNumeric)
 def cast(dtype, a):
     # AutoGrad does not respect the `copy` flag, so check that manually.
