@@ -24,6 +24,7 @@ __all__ = [
     "isnan",
     "Device",
     "device",
+    "move_to_active_device",
     "zeros",
     "ones",
     "zero",
@@ -153,6 +154,19 @@ def device(name):
     return Device(name)
 
 
+@dispatch(Numeric)
+@abstract(promote=None)
+def move_to_active_device(a):  # pragma: no cover
+    """Move a tensor to the active device.
+
+    Args:
+        a (tensor): Tensor to move.
+
+    Returns:
+        tensor: `a` on the active device.
+    """
+
+
 @dispatch(DType, [Int])
 @abstract(promote=None)
 def zeros(dtype, *shape):  # pragma: no cover
