@@ -15,11 +15,16 @@ def isnan(a):
     return tf.math.is_nan(a)
 
 
-@dispatch(Numeric)
+@dispatch(TFNumeric)
 def device(a):
     return str(a.device)
 
 
+@dispatch(TFNumeric)
+def move_to_active_device(a):
+    return a
+
+
 @dispatch(TFDType, [Int])
 def zeros(dtype, *shape):
     return tf.zeros(shape, dtype=dtype)
